summaryrefslogtreecommitdiffstats
path: root/Modules/posixmodule.c
diff options
context:
space:
mode:
authorMark Dickinson <dickinsm@gmail.com>2009-02-21 20:27:01 (GMT)
committerMark Dickinson <dickinsm@gmail.com>2009-02-21 20:27:01 (GMT)
commit3e4caeb3bf2b2579861e9f3379e3508fbb30549c (patch)
tree05385e9530059fe3608194b2e8d6f9e57d797220 /Modules/posixmodule.c
parenta12a86e956f949bd145cef247a95ed742386c70b (diff)
downloadcpython-3e4caeb3bf2b2579861e9f3379e3508fbb30549c.zip
cpython-3e4caeb3bf2b2579861e9f3379e3508fbb30549c.tar.gz
cpython-3e4caeb3bf2b2579861e9f3379e3508fbb30549c.tar.bz2
Issue #5341: Fix a variety of spelling errors.
Diffstat (limited to 'Modules/posixmodule.c')
-rw-r--r--Modules/posixmodule.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/Modules/posixmodule.c b/Modules/posixmodule.c
index 4f27cd1..1e5e3e5 100644
--- a/Modules/posixmodule.c
+++ b/Modules/posixmodule.c
@@ -2484,7 +2484,7 @@ posix_listdir(PyObject *self, PyObject *args)
static PyObject *
posix__getfullpathname(PyObject *self, PyObject *args)
{
/* assume encoded strings wont more than double no of chars */
char inbuf[MAX_PATH*2];
char *inbufp = inbuf;
Py_ssize_t insize = sizeof(inbuf);
@@ -5113,7 +5113,7 @@ _PyPopenCreateProcess(char *cmdstring,
"Your program accessed mem currently in use at xxx"
and a hopeful warning about the stability of your
system.
- Cost is Ctrl+C wont kill children, but anyone
+ Cost is Ctrl+C won't kill children, but anyone
who cares can have a go!
*/
dwProcessFlags |= CREATE_NEW_CONSOLE;
@@ -2484,7 +2484,7 @@ posix_listdir(PyObject *self, PyObject *args)
posix__getfullpathname(PyObject *self, PyObject *args)
{
- /* assume encoded strings wont more than double no of chars */
+ /* assume encoded strings won't more than double no of chars */
char inbuf[MAX_PATH*2];
char *inbufp = inbuf;